@@ -59,7 +59,7 @@ class CEvent extends CApiService {
 	 * @param array $options['eventids']
 	 * @param array $options['applicationids']
 	 * @param array $options['status']
-	 * @param array $options['editable']
+	 * @param bool  $options['editable']
 	 * @param array $options['count']
 	 * @param array $options['pattern']
 	 * @param array $options['limit']
@@ -69,8 +69,6 @@ class CEvent extends CApiService {
 	 */
 	public function get($options = []) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userid = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> [$this->fieldId('eventid')],
@@ -88,7 +86,7 @@ class CEvent extends CApiService {
 			'applicationids'			=> null,
 			'objectids'					=> null,
 
-			'editable'					=> null,
+			'editable'					=> false,
 			'object'					=> EVENT_OBJECT_TRIGGER,
 			'source'					=> EVENT_SOURCE_TRIGGERS,
 			'severities'				=> null,
@@ -131,7 +129,7 @@ class CEvent extends CApiService {
 		$sqlParts['where'][] = 'e.object='.zbx_dbstr($options['object']);
 
 		// editable + PERMISSION CHECK
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			// triggers
 			if ($options['object'] == EVENT_OBJECT_TRIGGER) {
 				// specific triggers
@@ -145,12 +143,14 @@ class CEvent extends CApiService {
 				}
 				// all triggers
 				else {
+					$userGroups = getUserGroupsByUserId(self::$userData['userid']);
+
 					$sqlParts['where'][] = 'NOT EXISTS ('.
 							'SELECT NULL'.
 							' FROM functions f,items i,hosts_groups hgg'.
 								' LEFT JOIN rights r'.
 									' ON r.id=hgg.groupid'.
-										' AND '.dbConditionInt('r.groupid', getUserGroupsByUserId($userid)).
+										' AND '.dbConditionInt('r.groupid', $userGroups).
 							' WHERE e.objectid=f.triggerid'.
 								' AND f.itemid=i.itemid'.
 								' AND i.hostid=hgg.hostid'.
@@ -184,12 +184,14 @@ class CEvent extends CApiService {
 				}
 				// all items and LLD rules
 				else {
+					$userGroups = getUserGroupsByUserId(self::$userData['userid']);
+
 					$sqlParts['where'][] = 'EXISTS ('.
 							'SELECT NULL'.
 							' FROM items i,hosts_groups hgg'.
 								' JOIN rights r'.
 									' ON r.id=hgg.groupid'.
-										' AND '.dbConditionInt('r.groupid', getUserGroupsByUserId($userid)).
+										' AND '.dbConditionInt('r.groupid', $userGroups).
 							' WHERE e.objectid=i.itemid'.
 								' AND i.hostid=hgg.hostid'.
 							' GROUP BY hgg.hostid'.
@@ -565,6 +567,7 @@ class CEvent extends CApiService {
 
 				$sqlParts['select']['r_eventid'] = 'er1.r_eventid';
 				$sqlParts['left_join'][] = ['from' => 'event_recovery er1', 'on' => 'er1.eventid=e.eventid'];
+				$sqlParts['left_table'] = 'e';
 			}
 
 			if ($this->outputIsRequested('c_eventid', $options['output'])
@@ -583,6 +586,7 @@ class CEvent extends CApiService {
 				}
 
 				$sqlParts['left_join'][] = ['from' => 'event_recovery er2', 'on' => 'er2.r_eventid=e.eventid'];
+				$sqlParts['left_table'] = 'e';
 			}
 
 			if ($options['selectRelatedObject'] !== null || $options['selectHosts'] !== null) {
