@@ -31,18 +31,19 @@ class CImage extends CApiService {
 	/**
 	 * Get images data
 	 *
-	 * @param array $options
-	 * @param array $options['itemids']
-	 * @param array $options['hostids']
-	 * @param array $options['groupids']
-	 * @param array $options['triggerids']
-	 * @param array $options['imageids']
-	 * @param boolean $options['status']
-	 * @param boolean $options['editable']
-	 * @param boolean $options['count']
+	 * @param array  $options
+	 * @param array  $options['itemids']
+	 * @param array  $options['hostids']
+	 * @param array  $options['groupids']
+	 * @param array  $options['triggerids']
+	 * @param array  $options['imageids']
+	 * @param bool   $options['status']
+	 * @param bool   $options['editable']
+	 * @param bool   $options['count']
 	 * @param string $options['pattern']
-	 * @param int $options['limit']
+	 * @param int    $options['limit']
 	 * @param string $options['order']
+	 *
 	 * @return array|boolean image data as array or false if error
 	 */
 	public function get($options = []) {
@@ -63,15 +64,15 @@ class CImage extends CApiService {
 			'filter'					=> null,
 			'search'					=> null,
 			'searchByAny'				=> null,
-			'startSearch'				=> null,
-			'excludeSearch'				=> null,
+			'startSearch'				=> false,
+			'excludeSearch'				=> false,
 			'searchWildcardsEnabled'	=> null,
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
 			'select_image'				=> null,
-			'editable'					=> null,
-			'countOutput'				=> null,
-			'preservekeys'				=> null,
+			'editable'					=> false,
+			'countOutput'				=> false,
+			'preservekeys'				=> false,
 			'sortfield'					=> '',
 			'sortorder'					=> '',
 			'limit'						=> null
@@ -79,8 +80,8 @@ class CImage extends CApiService {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + PERMISSION CHECK
-		if (!is_null($options['editable']) && self::$userData['type'] < USER_TYPE_ZABBIX_ADMIN) {
-			return $result;
+		if ($options['editable'] && self::$userData['type'] < USER_TYPE_ZABBIX_ADMIN) {
+			return [];
 		}
 
 		// imageids
@@ -144,13 +145,13 @@ class CImage extends CApiService {
 		if (!is_null($options['select_image'])) {
 			$dbImg = DBselect('SELECT i.imageid,i.image FROM images i WHERE '.dbConditionInt('i.imageid', $imageids));
 			while ($img = DBfetch($dbImg)) {
-				// PostgreSQL and SQLite images are stored escaped in the DB
+				// PostgreSQL images are stored escaped in the DB
 				$img['image'] = zbx_unescape_image($img['image']);
 				$result[$img['imageid']]['image'] = base64_encode($img['image']);
 			}
 		}
 
-		if (is_null($options['preservekeys'])) {
+		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
 		}
 		return $result;
@@ -227,13 +228,6 @@ class CImage extends CApiService {
 						self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
 					}
 				break;
-				case ZBX_DB_SQLITE3:
-					$values['image'] = zbx_dbstr(bin2hex($image['image']));
-					$sql = 'INSERT INTO images ('.implode(', ', array_keys($values)).') VALUES ('.implode(', ', $values).')';
-					if (!DBexecute($sql)) {
-						self::exception(ZBX_API_ERROR_PARAMETERS, 'DBerror');
-					}
-				break;
 				case ZBX_DB_MYSQL:
 						$values['image'] = zbx_dbstr($image['image']);
 						$sql = 'INSERT INTO images ('.implode(', ', array_keys($values)).') VALUES ('.implode(', ', $values).')';
@@ -289,10 +283,6 @@ class CImage extends CApiService {
 						$values['image'] = "'".pg_escape_bytea($image['image'])."'";
 						break;
 
-					case ZBX_DB_SQLITE3:
-						$values['image'] = zbx_dbstr(bin2hex($image['image']));
-						break;
-
 					case ZBX_DB_MYSQL:
 						$values['image'] = zbx_dbstr($image['image']);
 						break;
@@ -572,7 +562,7 @@ class CImage extends CApiService {
 	 * @return array				The resulting SQL parts array
 	 */
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
-		if ($options['countOutput'] === null) {
+		if (!$options['countOutput']) {
 			if ($options['output'] == API_OUTPUT_EXTEND) {
 				$options['output'] = ['imageid', 'imagetype', 'name'];
 			}
